"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.confirmForgotPassword = void 0;
const client_cognito_identity_provider_1 = require("@aws-sdk/client-cognito-identity-provider");
const calculateSecretHash_1 = require("./utils/calculateSecretHash");
const getUserPoolClientSecret_1 = require("./getUserPoolClientSecret");
const authenticateUser_1 = require("./authenticateUser");
const confirmForgotPassword = (userPoolId, clientId, region, code, username, password) => __awaiter(void 0, void 0, void 0, function* () {
    const cognitoClient = new client_cognito_identity_provider_1.CognitoIdentityProviderClient({ region });
    const clientSecret = yield (0, getUserPoolClientSecret_1.getUserPoolClientSecret)(userPoolId, clientId, region);
    const secretHash = (0, calculateSecretHash_1.calculateSecretHash)(username, clientId, clientSecret);
    const params = {
        ClientId: clientId,
        ConfirmationCode: code,
        SecretHash: secretHash,
        Password: password,
        Username: username,
    };
    yield cognitoClient.send(new client_cognito_identity_provider_1.ConfirmForgotPasswordCommand(params));
    // Authenticate the user
    const authResponse = yield (0, authenticateUser_1.authenticateUser)(userPoolId, clientId, region, username, password);
    return authResponse;
});
exports.confirmForgotPassword = confirmForgotPassword;
