"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.putItem = exports.getDynamoValueTypeFromKvsKey = exports.readKvsAttributeValue = void 0;
const client_dynamodb_1 = require("@aws-sdk/client-dynamodb");
const lodash_1 = require("lodash");
const convertObjectToDynamoMap_1 = require("./convertObjectToDynamoMap");
const readKvsAttributeValue = (item, key) => {
    const value = (0, lodash_1.get)(item, key.key);
    return {
        key,
        value,
    };
};
exports.readKvsAttributeValue = readKvsAttributeValue;
const getDynamoValueTypeFromKvsKey = (key) => {
    switch (key.type) {
        case 'string':
            return 'S';
        case 'number':
            return 'N';
        case 'binary':
            return 'B';
    }
};
exports.getDynamoValueTypeFromKvsKey = getDynamoValueTypeFromKvsKey;
function putItem(tableName, item, attributes, options, region) {
    return __awaiter(this, void 0, void 0, function* () {
        const dynamoClient = new client_dynamodb_1.DynamoDBClient({ region });
        // Read all the values from the item
        const dynamoProps = attributes
            .filter((a, index, self) => index === self.findIndex((t) => t.key === a.key))
            .reduce((acc, attribute) => {
            const { key, value } = (0, exports.readKvsAttributeValue)(item, attribute);
            const attributeValue = {
                [(0, exports.getDynamoValueTypeFromKvsKey)(key)]: value,
            };
            acc[key.key] = attributeValue;
            return acc;
        }, {});
        yield dynamoClient.send(new client_dynamodb_1.PutItemCommand({
            TableName: tableName,
            Item: (0, convertObjectToDynamoMap_1.convertObjectToDynamoMap)(item),
        }));
    });
}
exports.putItem = putItem;
